@@ -18,6 +18,10 @@ module Vagrant
         # to NOT be metadata.
         METADATA_SIZE_LIMIT = 20971520
 
+        # This is the amount of time to "resume" downloads if a partial box
+        # file already exists.
+        RESUME_DELAY = 24 * 60 * 60
+
         def initialize(app, env)
           @app    = app
           @logger = Log4r::Logger.new("vagrant::action::builtin::box_add")
@@ -30,7 +34,7 @@ module Vagrant
             u = u.gsub("\\", "/")
             if Util::Platform.windows? && u =~ /^[a-z]:/i
               # On Windows, we need to be careful about drive letters
-              u = "file://#{URI.escape(u)}"
+              u = "file:///#{URI.escape(u)}"
             end
 
             if u =~ /^[a-z0-9]+:.*$/i && !u.start_with?("file://")
@@ -253,7 +257,7 @@ module Vagrant
           end
 
           provider_url = metadata_provider.url
-          if url != authenticated_url
+          if provider_url != authenticated_url
             # Authenticate the provider URL since we're using auth
             hook_env    = env[:hook].call(:authenticate_box_url, box_urls: [provider_url])
             authed_urls = hook_env[:box_urls]
@@ -261,7 +265,7 @@ module Vagrant
               raise "Bad box authentication hook, did not generate proper results."
             end
             provider_url = authed_urls[0]
-          end
+        end
 
           box_add(
             [[provider_url, metadata_provider.url]],
@@ -393,7 +397,7 @@ module Vagrant
             if env[:box_clean]
               @logger.info("Cleaning existing temp box file.")
               delete = true
-            elsif temp_path.mtime.to_i < (Time.now.to_i - 6 * 60 * 60)
+            elsif temp_path.mtime.to_i < (Time.now.to_i - RESUME_DELAY)
               @logger.info("Existing temp file is too old. Removing.")
               delete = true
             end
@@ -468,6 +472,8 @@ module Vagrant
           if uri.scheme == "file"
             url = uri.path
             url ||= uri.opaque
+            #7570 Strip leading slash left in front of drive letter by uri.path
+            Util::Platform.windows? && url.gsub!(/^\/([a-zA-Z]:)/, '\1')
 
             begin
               File.open(url, "r") do |f|
