@@ -9,6 +9,7 @@ require 'log4r'
 
 require 'vagrant/util/file_mode'
 require 'vagrant/util/platform'
+require "vagrant/util/silence_warnings"
 require "vagrant/vagrantfile"
 require "vagrant/version"
 
@@ -80,7 +81,7 @@ module Vagrant
       }.merge(opts || {})
 
       # Set the default working directory to look for the vagrantfile
-      opts[:cwd] ||= ENV["VAGRANT_CWD"] if ENV.has_key?("VAGRANT_CWD")
+      opts[:cwd] ||= ENV["VAGRANT_CWD"] if ENV.key?("VAGRANT_CWD")
       opts[:cwd] ||= Dir.pwd
       opts[:cwd] = Pathname.new(opts[:cwd])
       if !opts[:cwd].directory?
@@ -94,7 +95,7 @@ module Vagrant
       # Set the Vagrantfile name up. We append "Vagrantfile" and "vagrantfile" so that
       # those continue to work as well, but anything custom will take precedence.
       opts[:vagrantfile_name] ||= ENV["VAGRANT_VAGRANTFILE"] if \
-        ENV.has_key?("VAGRANT_VAGRANTFILE")
+        ENV.key?("VAGRANT_VAGRANTFILE")
       opts[:vagrantfile_name] = [opts[:vagrantfile_name]] if \
         opts[:vagrantfile_name] && !opts[:vagrantfile_name].is_a?(Array)
 
@@ -156,13 +157,28 @@ module Vagrant
       end
 
       # Setup the local data directory. If a configuration path is given,
-      # then it is expanded relative to the working directory. Otherwise,
-      # we use the default which is expanded relative to the root path.
-      opts[:local_data_path] ||= ENV["VAGRANT_DOTFILE_PATH"]
-      opts[:local_data_path] ||= root_path.join(DEFAULT_LOCAL_DATA) if !root_path.nil?
+      # it is expanded relative to the root path. Otherwise, we use the
+      # default (which is also expanded relative to the root path).
+      if !root_path.nil?
+        if !(ENV["VAGRANT_DOTFILE_PATH"] or "").empty? && !opts[:child]
+          opts[:local_data_path] ||= root_path.join(ENV["VAGRANT_DOTFILE_PATH"])
+        else
+          opts[:local_data_path] ||= root_path.join(DEFAULT_LOCAL_DATA)
+        end
+      end
       if opts[:local_data_path]
         @local_data_path = Pathname.new(File.expand_path(opts[:local_data_path], @cwd))
       end
+      @logger.debug("Effective local data path: #{@local_data_path}")
+
+      # If we have a root path, load the ".vagrantplugins" file.
+      if root_path
+        plugins_file = root_path.join(".vagrantplugins")
+        if plugins_file.file?
+          @logger.info("Loading plugins file: #{plugins_file}")
+          load plugins_file
+        end
+      end
 
       setup_local_data_path
 
@@ -298,7 +314,8 @@ module Vagrant
     # @return [Symbol] Name of the default provider.
     def default_provider(**opts)
       opts[:exclude]       = Set.new(opts[:exclude]) if opts[:exclude]
-      opts[:force_default] = true if !opts.has_key?(:force_default)
+      opts[:force_default] = true if !opts.key?(:force_default)
+      opts[:check_usable] = true if !opts.key?(:check_usable)
 
       default = ENV["VAGRANT_DEFAULT_PROVIDER"]
       default = nil if default == ""
@@ -308,6 +325,30 @@ module Vagrant
       # that (the default behavior)
       return default if default && opts[:force_default]
 
+      # Determine the config to use to look for provider definitions. By
+      # default it is the global but if we're targeting a specific machine,
+      # then look there.
+      root_config = vagrantfile.config
+      if opts[:machine]
+        machine_info = vagrantfile.machine_config(opts[:machine], nil, nil)
+        root_config = machine_info[:config]
+      end
+
+      # Get the list of providers within our configuration and assign
+      # a priority to each in the order they exist so that we try these first.
+      config = {}
+      root_config.vm.__providers.reverse.each_with_index do |key, idx|
+        config[key] = idx + 1
+      end
+
+      # Determine the max priority so that we can add the config priority
+      # to that to make sure it is highest.
+      max_priority = 0
+      Vagrant.plugin("2").manager.providers.each do |key, data|
+        priority = data[1][:priority]
+        max_priority = priority if priority > max_priority
+      end
+
       ordered = []
       Vagrant.plugin("2").manager.providers.each do |key, data|
         impl  = data[0]
@@ -316,10 +357,19 @@ module Vagrant
         # Skip excluded providers
         next if opts[:exclude] && opts[:exclude].include?(key)
 
-        # Skip providers that can't be defaulted
-        next if popts.has_key?(:defaultable) && !popts[:defaultable]
+        # Skip providers that can't be defaulted, unless they're in our
+        # config, in which case someone made our decision for us.
+        if !config.key?(key)
+          next if popts.key?(:defaultable) && !popts[:defaultable]
+        end
 
-        ordered << [popts[:priority], key, impl, popts]
+        # The priority is higher if it is in our config. Otherwise, it is
+        # the priority it set PLUS the length of the config to make sure it
+        # is never higher than the configuration keys.
+        priority = popts[:priority]
+        priority = config[key] + max_priority if config.key?(key)
+
+        ordered << [priority, key, impl, popts]
       end
 
       # Order the providers by priority. Higher values are tried first.
@@ -333,11 +383,32 @@ module Vagrant
 
       # Find the matching implementation
       ordered.each do |_, key, impl, _|
+        return key if !opts[:check_usable]
         return key if impl.usable?(false)
       end
 
-      # If all else fails, return VirtualBox
-      return :virtualbox
+      # No providers available is a critical error for Vagrant.
+      raise Errors::NoDefaultProvider
+    end
+
+    # Returns whether or not we know how to install the provider with
+    # the given name.
+    #
+    # @return [Boolean]
+    def can_install_provider?(name)
+      host.capability?(provider_install_key(name))
+    end
+
+    # Installs the provider with the given name.
+    #
+    # This will raise an exception if we don't know how to install the
+    # provider with the given name. You should guard this call with
+    # `can_install_provider?` for added safety.
+    #
+    # An exception will be raised if there are any failures installing
+    # the provider.
+    def install_provider(name)
+      host.capability(provider_install_key(name))
     end
 
     # Returns the collection of boxes for the environment.
@@ -371,6 +442,28 @@ module Vagrant
       @config_loader
     end
 
+    # Loads another environment for the given Vagrantfile, sharing as much
+    # useful state from this Environment as possible (such as UI and paths).
+    # Any initialization options can be overidden using the opts hash.
+    #
+    # @param [String] vagrantfile Path to a Vagrantfile
+    # @return [Environment]
+    def environment(vagrantfile, **opts)
+      path = File.expand_path(vagrantfile, root_path)
+      file = File.basename(path)
+      path = File.dirname(path)
+
+      Util::SilenceWarnings.silence! do
+        Environment.new({
+          child:     true,
+          cwd:       path,
+          home_path: home_path,
+          ui_class:  ui_class,
+          vagrantfile_name: file,
+        }.merge(opts))
+      end
+    end
+
     # This defines a hook point where plugin action hooks that are registered
     # against the given name will be run in the context of this environment.
     #
@@ -484,7 +577,13 @@ module Vagrant
       if name != "dotlock"
         lock("dotlock", retry: true) do
           f.close
-          File.delete(lock_path)
+          begin
+            File.delete(lock_path)
+          rescue
+            @logger.error(
+              "Failed to delete lock file #{lock_path} - some other thread " +
+              "might be trying to acquire it. ignoring this error")
+          end
         end
       end
 
@@ -497,6 +596,41 @@ module Vagrant
       end
     end
 
+    # This executes the push with the given name, raising any exceptions that
+    # occur.
+    #
+    # Precondition: the push is not nil and exists.
+    def push(name)
+      @logger.info("Getting push: #{name}")
+
+      name = name.to_sym
+
+      pushes = self.vagrantfile.config.push.__compiled_pushes
+      if !pushes.key?(name)
+        raise Vagrant::Errors::PushStrategyNotDefined,
+          name: name,
+          pushes: pushes.keys
+      end
+
+      strategy, config = pushes[name]
+      push_registry = Vagrant.plugin("2").manager.pushes
+      klass, _ = push_registry.get(strategy)
+      if klass.nil?
+        raise Vagrant::Errors::PushStrategyNotLoaded,
+          name: strategy,
+          pushes: push_registry.keys
+      end
+
+      klass.new(self, config).push
+    end
+
+    # The list of pushes defined in this Vagrantfile.
+    #
+    # @return [Array<Symbol>]
+    def pushes
+      self.vagrantfile.config.push.__compiled_pushes.keys
+    end
+
     # This returns a machine with the proper provider for this environment.
     # The machine named by `name` must be in this environment.
     #
@@ -519,7 +653,7 @@ module Vagrant
         @machines.delete(cache_key)
       end
 
-      if @machines.has_key?(cache_key)
+      if @machines.key?(cache_key)
         @logger.info("Returning cached machine: #{name} (#{provider})")
         return @machines[cache_key]
       end
@@ -527,10 +661,8 @@ module Vagrant
       @logger.info("Uncached load of machine.")
 
       # Determine the machine data directory and pass it to the machine.
-      # XXX: Permissions error here.
       machine_data_path = @local_data_path.join(
         "machines/#{name}/#{provider}")
-      FileUtils.mkdir_p(machine_data_path)
 
       # Create the machine and cache it for future calls. This will also
       # return the machine from this method.
@@ -706,7 +838,7 @@ module Vagrant
 
     # This creates the local data directory and show an error if it
     # couldn't properly be created.
-    def setup_local_data_path
+    def setup_local_data_path(force=false)
       if @local_data_path.nil?
         @logger.warn("No local data path is set. Local data cannot be stored.")
         return
@@ -721,6 +853,9 @@ module Vagrant
         upgrade_v1_dotfile(@local_data_path)
       end
 
+      # If we don't have a root path, we don't setup anything
+      return if !force && root_path.nil?
+
       begin
         @logger.debug("Creating: #{@local_data_path}")
         FileUtils.mkdir_p(@local_data_path)
@@ -779,10 +914,19 @@ module Vagrant
       nil
     end
 
+    # Returns the key used for the host capability for provider installs
+    # of the given name.
+    def provider_install_key(name)
+      "provider_install_#{name}".to_sym
+    end
+
     # This upgrades a home directory that was in the v1.1 format to the
     # v1.5 format. It will raise exceptions if anything fails.
     def upgrade_home_path_v1_1
-      @ui.ask(I18n.t("vagrant.upgrading_home_path_v1_5"))
+      if !ENV["VAGRANT_UPGRADE_SILENT_1_5"]
+        @ui.ask(I18n.t("vagrant.upgrading_home_path_v1_5"))
+      end
+
       collection = BoxCollection.new(
         @home_path.join("boxes"), temp_dir_root: tmp_path)
       collection.upgrade_v1_1_v1_5
@@ -830,7 +974,7 @@ module Vagrant
 
       # Now, we create the actual local data directory. This should succeed
       # this time since we renamed the old conflicting V1.
-      setup_local_data_path
+      setup_local_data_path(true)
 
       if json_data["active"]
         @logger.debug("Upgrading to V2 style for each active VM")
