@@ -340,6 +340,10 @@ module Vagrant
       error_key(:downloader_interrupted)
     end
 
+    class DownloaderChecksumError < VagrantError
+      error_key(:downloader_checksum_error)
+    end
+
     class EnvInval < VagrantError
       error_key(:env_inval)
     end
@@ -456,6 +460,10 @@ module Vagrant
       error_key(:nfs_bad_exports)
     end
 
+    class NFSExportsFailed < VagrantError
+      error_key(:nfs_exports_failed)
+    end
+
     class NFSCantReadExports < VagrantError
       error_key(:nfs_cant_read_exports)
     end
@@ -580,6 +588,10 @@ module Vagrant
       error_key(:plugin_uninstall_system)
     end
 
+    class PluginInitError < VagrantError
+      error_key(:plugin_init_error)
+    end
+
     class PushesNotDefined < VagrantError
       error_key(:pushes_not_defined)
     end
@@ -608,6 +620,10 @@ module Vagrant
       error_key(:rsync_not_installed_in_guest)
     end
 
+    class RSyncGuestInstallError < VagrantError
+      error_key(:rsync_guest_install_error)
+    end
+
     class SCPPermissionDenied < VagrantError
       error_key(:scp_permission_denied)
     end
