@@ -5,7 +5,7 @@ module VagrantPlugins
         def build_install_opts(o, options)
           options[:plugin_sources] = [
             "https://rubygems.org",
-            "http://gems.hashicorp.com",
+            "https://gems.hashicorp.com",
           ]
 
           o.on("--entry-point NAME", String,
@@ -13,15 +13,6 @@ module VagrantPlugins
             options[:entry_point] = entry_point
           end
 
-          # @deprecated
-          o.on("--plugin-prerelease",
-               "Allow prerelease versions of this plugin.") do |plugin_prerelease|
-            puts "--plugin-prelease is deprecated and will be removed in the next"
-            puts "version of Vagrant. It has no effect now. Use the '--plugin-version'"
-            puts "flag to get a specific pre-release version."
-            puts
-          end
-
           o.on("--plugin-clean-sources",
             "Remove all plugin sources defined so far (including defaults)") do |clean|
             options[:plugin_sources] = [] if clean
