@@ -8,16 +8,18 @@ module VagrantPlugins
       class Uninstall < Base
         def execute
           opts = OptionParser.new do |o|
-            o.banner = "Usage: vagrant plugin uninstall <name> [-h]"
+            o.banner = "Usage: vagrant plugin uninstall <name> [<name2> <name3> ...] [-h]"
           end
 
           # Parse the options
           argv = parse_options(opts)
           return if !argv
-          raise Vagrant::Errors::CLIInvalidUsage, :help => opts.help.chomp if argv.length < 1
+          raise Vagrant::Errors::CLIInvalidUsage, help: opts.help.chomp if argv.length < 1
 
-          # Uninstall the gem
-          action(Action.action_uninstall, :plugin_name => argv[0])
+          # Uninstall the gems
+          argv.each do |gem|
+            action(Action.action_uninstall, plugin_name: gem)
+          end
 
           # Success, exit status 0
           0
