@@ -43,7 +43,7 @@ module VagrantPlugins
         # Clear the sources so that installation uses custom sources
         old_sources = Gem.sources
         Gem.sources = Gem.default_sources
-        Gem.sources << "http://gems.hashicorp.com"
+        Gem.sources << "https://gems.hashicorp.com"
 
         # Use a silent UI so that we have no output
         Gem::DefaultUserInteraction.use_ui(Gem::SilentUI.new) do
