@@ -37,7 +37,10 @@ module VagrantPlugins
             ssh_host: ssh_info[:host],
             ssh_port: ssh_info[:port],
             ssh_user: ssh_info[:username],
+            keys_only: ssh_info[:keys_only],
+            paranoid: ssh_info[:paranoid],
             private_key_path: ssh_info[:private_key_path],
+            log_level: ssh_info[:log_level],
             forward_agent: ssh_info[:forward_agent],
             forward_x11:   ssh_info[:forward_x11],
             proxy_command: ssh_info[:proxy_command],
