@@ -8,16 +8,17 @@ module VagrantPlugins
           if !comm.test("hostname -f | grep '^#{name}$'", sudo: false)
             basename = name.split(".", 2)[0]
 
-            comm.sudo <<-EOH.gsub(/^ {14}/, '')
-              set -e
-
+            # LocalHostName should not contain dots - it is used by Bonjour and
+            # visible through file sharing services.
+            comm.sudo <<-EOH.gsub(/^ */, '')
               # Set hostname
-              scutil --set ComputerName '#{name}'
-              scutil --set HostName '#{name}'
-
-              # LocalHostName should not contain dots - it is used by Bonjour and
-              # visible through file sharing services.
-              scutil --set LocalHostName '#{basename}'
+              scutil --set ComputerName '#{name}' &&
+                scutil --set HostName '#{name}' &&
+                scutil --set LocalHostName '#{basename}'
+              result=$?
+              if [ $result -ne 0 ]; then
+                exit $result
+              fi
 
               hostname '#{name}'
 
@@ -27,8 +28,8 @@ module VagrantPlugins
 
               # Prepend ourselves to /etc/hosts - sed on bsd is sad
               grep -w '#{name}' /etc/hosts || {
-                echo -e '127.0.0.1\\t#{name}\\t#{basename}' | cat - /etc/hosts > /tmp/tmp-hosts
-                mv /tmp/tmp-hosts /etc/hosts
+                echo -e '127.0.0.1\\t#{name}\\t#{basename}' | cat - /etc/hosts > /tmp/tmp-hosts &&
+                  mv /tmp/tmp-hosts /etc/hosts
               }
             EOH
           end
