@@ -8,8 +8,6 @@ module VagrantPlugins
           if !comm.test("hostname -f | grep '^#{name}$'", sudo: false)
             basename = name.split(".", 2)[0]
             comm.sudo <<-EOH.gsub(/^ {14}/, "")
-              set -e
-
               # Set the hostname
               hostname '#{basename}'
               echo "hostname=#{basename}" > /etc/conf.d/hostname
@@ -20,8 +18,8 @@ module VagrantPlugins
 
               # Prepend ourselves to /etc/hosts
               grep -w '#{name}' /etc/hosts || {
-                echo -e '127.0.0.1\\t#{name}\\t#{basename}' | cat - /etc/hosts > /tmp/tmp-hosts
-                mv /tmp/tmp-hosts /etc/hosts
+                echo -e '127.0.0.1\\t#{name}\\t#{basename}' | cat - /etc/hosts > /tmp/tmp-hosts &&
+                  mv /tmp/tmp-hosts /etc/hosts
               }
             EOH
           end
