@@ -6,20 +6,25 @@ module VagrantPlugins
       name "OmniOS guest."
       description "OmniOS guest support."
 
-      guest("omnios", "solaris")  do
-        require File.expand_path("../guest", __FILE__)
+      guest(:omnios, :solaris) do
+        require_relative "guest"
         Guest
       end
 
-      guest_capability("omnios", "change_host_name") do
+      guest_capability(:omnios, :change_host_name) do
         require_relative "cap/change_host_name"
         Cap::ChangeHostName
       end
 
-      guest_capability("omnios", "mount_nfs_folder") do
+      guest_capability(:omnios, :mount_nfs_folder) do
         require_relative "cap/mount_nfs_folder"
         Cap::MountNFSFolder
       end
+
+      guest_capability(:omnios, :rsync_install) do
+        require_relative "cap/rsync"
+        Cap::RSync
+      end
     end
   end
 end
