@@ -31,8 +31,12 @@ module VagrantPlugins
                 sed -i'' '1i 127.0.0.1\\t#{name}\\t#{basename}' /etc/hosts
               }
 
-              # Restart network
-              service network restart
+              # Restart network (through NetworkManager if running)
+              if service NetworkManager status 2>&1 | grep -q running; then
+                service NetworkManager restart
+              else
+                service network restart
+              fi
             EOH
           end
         end
