@@ -11,7 +11,7 @@ module VagrantPlugins
           begin
             machine.communicate.execute(
               "#{machine.config.smartos.suexec_cmd} /usr/sbin/shutdown -y -i5 -g0")
-          rescue IOError
+          rescue IOError, Vagrant::Errors::SSHDisconnected
             # Ignore, this probably means connection closed because it
             # shut down.
           end
