@@ -15,7 +15,7 @@ module VagrantPlugins
           begin
             machine.communicate.execute(
               "#{machine.config.solaris11.suexec_cmd} /usr/sbin/shutdown -y -i5 -g0")
-          rescue IOError
+          rescue IOError, Vagrant::Errors::SSHDisconnected
             # Ignore, this probably means connection closed because it
             # shut down.
           end
