@@ -12,6 +12,8 @@ module VagrantPlugins
       attr_accessor :vlan_id # VLAN ID for network interface for the virtual machine. @return [Integer]
       attr_accessor :mac # MAC address for network interface for the virtual machine. @return [String]
       attr_accessor :differencing_disk # Create differencing disk instead of cloning whole VHD [Boolean]
+      attr_accessor :auto_start_action #action on automatic start of VM. Values: Nothing, StartIfRunning, Start
+      attr_accessor :auto_stop_action #action on automatic stop of VM. Values: ShutDown, TurnOff, Save
 
       def initialize
         @ip_address_timeout = UNSET_VALUE
@@ -22,6 +24,8 @@ module VagrantPlugins
         @vlan_id  = UNSET_VALUE
         @mac  = UNSET_VALUE
         @differencing_disk = UNSET_VALUE
+        @auto_start_action = UNSET_VALUE
+        @auto_stop_action = UNSET_VALUE
       end
 
       def finalize!
@@ -35,6 +39,8 @@ module VagrantPlugins
         @vlan_id = nil if @vlan_id == UNSET_VALUE
         @mac = nil if @mac == UNSET_VALUE
         @differencing_disk = false if @differencing_disk == UNSET_VALUE
+        @auto_start_action = nil if @auto_start_action == UNSET_VALUE
+        @auto_stop_action = nil if @auto_stop_action == UNSET_VALUE
       end
 
       def validate(machine)
