@@ -7,12 +7,12 @@ require File.expand_path("../base", __FILE__)
 module VagrantPlugins
   module ProviderVirtualBox
     module Driver
-      # Driver for VirtualBox 4.1.x
-      class Version_4_1 < Base
+      # Driver for VirtualBox 5.0.x
+      class Version_5_0 < Base
         def initialize(uuid)
           super()
 
-          @logger = Log4r::Logger.new("vagrant::provider::virtualbox_4_1")
+          @logger = Log4r::Logger.new("vagrant::provider::virtualbox_5_0")
           @uuid = uuid
         end
 
@@ -28,12 +28,23 @@ module VagrantPlugins
         def clear_shared_folders
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            if folder = line[/^SharedFolderNameMachineMapping\d+="(.+?)"$/, 1]
-              execute("sharedfolder", "remove", @uuid, "--name", folder)
+            if line =~ /^SharedFolderNameMachineMapping\d+="(.+?)"$/
+              execute("sharedfolder", "remove", @uuid, "--name", $1.to_s)
             end
           end
         end
 
+        def clonevm(master_id, snapshot_name)
+          machine_name = "temp_clone_#{(Time.now.to_f * 1000.0).to_i}_#{rand(100000)}"
+          args = ["--register", "--name", machine_name]
+          if snapshot_name
+            args += ["--snapshot", snapshot_name, "--options", "link"]
+          end
+
+          execute("clonevm", master_id, *args)
+          return get_machine_id(machine_name)
+        end
+
         def create_dhcp_server(network, options)
           execute("dhcpserver", "add", "--ifname", network,
                   "--ip", options[:dhcp_ip],
@@ -45,8 +56,8 @@ module VagrantPlugins
 
         def create_host_only_network(options)
           # Create the interface
-          interface = execute("hostonlyif", "create")
-          name = interface[/^Interface '(.+?)' was successfully created$/, 1]
+          execute("hostonlyif", "create") =~ /^Interface '(.+?)' was successfully created$/
+          name = $1.to_s
 
           # Get the IP so we can determine v4 vs v6
           ip = IPAddr.new(options[:adapter_ip])
@@ -60,6 +71,8 @@ module VagrantPlugins
             execute("hostonlyif", "ipconfig", name,
                     "--ipv6", options[:adapter_ip],
                     "--netmasklengthv6", options[:netmask].to_s)
+          else
+            raise "BUG: Unknown IP type: #{ip.inspect}"
           end
 
           # Return the details
@@ -71,24 +84,102 @@ module VagrantPlugins
           }
         end
 
+        def create_snapshot(machine_id, snapshot_name)
+          execute("snapshot", machine_id, "take", snapshot_name)
+        end
+
+        def delete_snapshot(machine_id, snapshot_name)
+          # Start with 0%
+          last = 0
+          total = ""
+          yield 0 if block_given?
+
+          # Snapshot and report the % progress
+          execute("snapshot", machine_id, "delete", snapshot_name) do |type, data|
+            if type == :stderr
+              # Append the data so we can see the full view
+              total << data.gsub("\r", "")
+
+              # Break up the lines. We can't get the progress until we see an "OK"
+              lines = total.split("\n")
+
+              # The progress of the import will be in the last line. Do a greedy
+              # regular expression to find what we're looking for.
+              match = /.+(\d{2})%/.match(lines.last)
+              if match
+                current = match[1].to_i
+                if current > last
+                  last = current
+                  yield current if block_given?
+                end
+              end
+            end
+          end
+        end
+
+        def list_snapshots(machine_id)
+          output = execute(
+            "snapshot", machine_id, "list", "--machinereadable",
+            retryable: true)
+
+          result = []
+          output.split("\n").each do |line|
+            if line =~ /^SnapshotName.*?="(.+?)"$/i
+              result << $1.to_s
+            end
+          end
+
+          result.sort
+        rescue Vagrant::Errors::VBoxManageError => e
+          d = e.extra_data
+          return [] if d[:stderr].include?("does not have") || d[:stdout].include?("does not have")
+          raise
+        end
+
+        def restore_snapshot(machine_id, snapshot_name)
+          # Start with 0%
+          last = 0
+          total = ""
+          yield 0 if block_given?
+
+          execute("snapshot", machine_id, "restore", snapshot_name) do |type, data|
+            if type == :stderr
+              # Append the data so we can see the full view
+              total << data.gsub("\r", "")
+
+              # Break up the lines. We can't get the progress until we see an "OK"
+              lines = total.split("\n")
+
+              # The progress of the import will be in the last line. Do a greedy
+              # regular expression to find what we're looking for.
+              match = /.+(\d{2})%/.match(lines.last)
+              if match
+                current = match[1].to_i
+                if current > last
+                  last = current
+                  yield current if block_given?
+                end
+              end
+            end
+          end
+        end
+
         def delete
           execute("unregistervm", @uuid, "--delete")
         end
 
         def delete_unused_host_only_networks
           networks = []
-          execute("list", "hostonlyifs").split("\n").each do |line|
-            if network = line[/^Name:\s+(.+?)$/, 1]
-              networks << network
-            end
+          execute("list", "hostonlyifs", retryable: true).split("\n").each do |line|
+            networks << $1.to_s if line =~ /^Name:\s+(.+?)$/
           end
 
-          execute("list", "vms").split("\n").each do |line|
-            if vm = line[/^".+?"\s+\{(.+?)\}$/, 1]
-              info = execute("showvminfo", vm, "--machinereadable", retryable: true)
-              info.split("\n").each do |line|
-                if adapter = line[/^hostonlyadapter\d+="(.+?)"$/, 1]
-                  networks.delete(adapter)
+          execute("list", "vms", retryable: true).split("\n").each do |line|
+            if line =~ /^".+?"\s+\{(.+?)\}$/
+              info = execute("showvminfo", $1.to_s, "--machinereadable", retryable: true)
+              info.split("\n").each do |inner_line|
+                if inner_line =~ /^hostonlyadapter\d+="(.+?)"$/
+                  networks.delete($1.to_s)
                 end
               end
             end
@@ -121,12 +212,12 @@ module VagrantPlugins
 
             if adapter[:hostonly]
               args.concat(["--hostonlyadapter#{adapter[:adapter]}",
-                          adapter[:hostonly]])
+                          adapter[:hostonly], "--cableconnected#{adapter[:adapter]}", "on"])
             end
 
             if adapter[:intnet]
               args.concat(["--intnet#{adapter[:adapter]}",
-                          adapter[:intnet]])
+                          adapter[:intnet], "--cableconnected#{adapter[:adapter]}", "on"])
             end
 
             if adapter[:mac_address]
@@ -167,6 +258,13 @@ module VagrantPlugins
           execute("modifyvm", @uuid, *args) if !args.empty?
         end
 
+        def get_machine_id(machine_name)
+          output = execute("list", "vms", retryable: true)
+          match = /^"#{Regexp.escape(machine_name)}" \{(.+?)\}$/.match(output)
+          return match[1].to_s if match
+          nil
+        end
+
         def halt
           execute("controlvm", @uuid, "poweroff")
         end
@@ -177,21 +275,62 @@ module VagrantPlugins
           output = ""
           total = ""
           last  = 0
-          execute("import", ovf) do |type, data|
+
+          # Dry-run the import to get the suggested name and path
+          @logger.debug("Doing dry-run import to determine parallel-safe name...")
+          output = execute("import", "-n", ovf)
+          result = /Suggested VM name "(.+?)"/.match(output)
+          if !result
+            raise Vagrant::Errors::VirtualBoxNoName, output: output
+          end
+          suggested_name = result[1].to_s
+
+          # Append millisecond plus a random to the path in case we're
+          # importing the same box elsewhere.
+          specified_name = "#{suggested_name}_#{(Time.now.to_f * 1000.0).to_i}_#{rand(100000)}"
+          @logger.debug("-- Parallel safe name: #{specified_name}")
+
+          # Build the specified name param list
+          name_params = [
+            "--vsys", "0",
+            "--vmname", specified_name,
+          ]
+
+          # Extract the disks list and build the disk target params
+          disk_params = []
+          disks = output.scan(/(\d+): Hard disk image: source image=.+, target path=(.+),/)
+          disks.each do |unit_num, path|
+            disk_params << "--vsys"
+            disk_params << "0"
+            disk_params << "--unit"
+            disk_params << unit_num
+            disk_params << "--disk"
+            if Vagrant::Util::Platform.windows?
+              # we use the block form of sub here to ensure that if the specified_name happens to end with a number (which is fairly likely) then
+              # we won't end up having the character sequence of a \ followed by a number be interpreted as a back reference.  For example, if
+              # specified_name were "abc123", then "\\abc123\\".reverse would be "\\321cba\\", and the \3 would be treated as a back reference by the sub
+              disk_params << path.reverse.sub("\\#{suggested_name}\\".reverse) { "\\#{specified_name}\\".reverse }.reverse # Replace only last occurrence
+            else
+              disk_params << path.reverse.sub("/#{suggested_name}/".reverse, "/#{specified_name}/".reverse).reverse # Replace only last occurrence
+            end
+          end
+
+          execute("import", ovf , *name_params, *disk_params) do |type, data|
             if type == :stdout
               # Keep track of the stdout so that we can get the VM name
               output << data
             elsif type == :stderr
               # Append the data so we can see the full view
-              total << data
+              total << data.gsub("\r", "")
 
               # Break up the lines. We can't get the progress until we see an "OK"
               lines = total.split("\n")
               if lines.include?("OK.")
                 # The progress of the import will be in the last line. Do a greedy
                 # regular expression to find what we're looking for.
-                if current = lines.last[/.+(\d{2})%/, 1]
-                  current = current.to_i
+                match = /.+(\d{2})%/.match(lines.last)
+                if match
+                  current = match[1].to_i
                   if current > last
                     last = current
                     yield current if block_given?
@@ -201,19 +340,11 @@ module VagrantPlugins
             end
           end
 
-          # Find the name of the VM name
-          name = output[/Suggested VM name "(.+?)"/, 1]
-          if !name
-            @logger.error("Couldn't find VM name in the output.")
-            return nil
-          end
+          return get_machine_id specified_name
+        end
 
-          output = execute("list", "vms")
-          if existing_vm = output[/^"#{Regexp.escape(name)}" \{(.+?)\}$/, 1]
-            return existing_vm
-          end
-
-          nil
+        def max_network_adapters
+          8
         end
 
         def read_forwarded_ports(uuid=nil, active_only=false)
@@ -227,19 +358,17 @@ module VagrantPlugins
           info.split("\n").each do |line|
             # This is how we find the nic that a FP is attached to,
             # since this comes first.
-            if nic = line[/^nic(\d+)=".+?"$/, 1]
-              current_nic = nic.to_i
-            end
+            current_nic = $1.to_i if line =~ /^nic(\d+)=".+?"$/
 
-            # If we care about active VMs only, then we check the state
-            # to verify the VM is running.
-            if active_only && (state = line[/^VMState="(.+?)"$/, 1] and state != "running")
-              return []
-            end
+              # If we care about active VMs only, then we check the state
+              # to verify the VM is running.
+              if active_only && line =~ /^VMState="(.+?)"$/ && $1.to_s != "running"
+                return []
+              end
 
             # Parse out the forwarded port information
-            if matcher = /^Forwarding.+?="(.+?),.+?,.*?,(.+?),.*?,(.+?)"$/.match(line)
-              result = [current_nic, matcher[1], matcher[2].to_i, matcher[3].to_i]
+            if line =~ /^Forwarding.+?="(.+?),.+?,.*?,(.+?),.*?,(.+?)"$/
+              result = [current_nic, $1.to_s, $2.to_i, $3.to_i]
               @logger.debug("  - #{result.inspect}")
               results << result
             end
@@ -253,14 +382,14 @@ module VagrantPlugins
             info = {}
 
             block.split("\n").each do |line|
-              if name = line[/^Name:\s+(.+?)$/, 1]
-                info[:name] = name
-              elsif ip = line[/^IPAddress:\s+(.+?)$/, 1]
-                info[:ip] = ip
-              elsif netmask = line[/^NetworkMask:\s+(.+?)$/, 1]
-                info[:netmask] = netmask
-              elsif status = line[/^Status:\s+(.+?)$/, 1]
-                info[:status] = status
+              if line =~ /^Name:\s+(.+?)$/
+                info[:name] = $1.to_s
+              elsif line =~ /^IPAddress:\s+(.+?)$/
+                info[:ip] = $1.to_s
+              elsif line =~ /^NetworkMask:\s+(.+?)$/
+                info[:netmask] = $1.to_s
+              elsif line =~ /^Status:\s+(.+?)$/
+                info[:status] = $1.to_s
               end
             end
 
@@ -295,20 +424,29 @@ module VagrantPlugins
         def read_guest_additions_version
           output = execute("guestproperty", "get", @uuid, "/VirtualBox/GuestAdd/Version",
                            retryable: true)
-          if value = output[/^Value: (.+?)$/, 1]
+          if output =~ /^Value: (.+?)$/
             # Split the version by _ since some distro versions modify it
             # to look like this: 4.1.2_ubuntu, and the distro part isn't
             # too important.
+            value = $1.to_s
             return value.split("_").first
           end
 
+          # If we can't get the guest additions version by guest property, try
+          # to get it from the VM info itself.
+          info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
+          info.split("\n").each do |line|
+            return $1.to_s if line =~ /^GuestAdditionsVersion="(.+?)"$/
+          end
+
           return nil
         end
 
         def read_guest_ip(adapter_number)
           ip = read_guest_property("/VirtualBox/GuestInfo/Net/#{adapter_number}/V4/IP")
           if !valid_ip_address?(ip)
-            raise Vagrant::Errors::VirtualBoxGuestPropertyNotFound, guest_property: "/VirtualBox/GuestInfo/Net/#{adapter_number}/V4/IP"
+            raise Vagrant::Errors::VirtualBoxGuestPropertyNotFound,
+              guest_property: "/VirtualBox/GuestInfo/Net/#{adapter_number}/V4/IP"
           end
 
           return ip
@@ -328,18 +466,18 @@ module VagrantPlugins
             info = {}
 
             block.split("\n").each do |line|
-              if name = line[/^Name:\s+(.+?)$/, 1]
-                info[:name] = name
-              elsif ip = line[/^IPAddress:\s+(.+?)$/, 1]
-                info[:ip] = ip
-              elsif netmask = line[/^NetworkMask:\s+(.+?)$/, 1]
-                info[:netmask] = netmask
+              if line =~ /^Name:\s+(.+?)$/
+                info[:name] = $1.to_s
+              elsif line =~ /^IPAddress:\s+(.+?)$/
+                info[:ip] = $1.to_s
+              elsif line =~ /^NetworkMask:\s+(.+?)$/
+                info[:netmask] = $1.to_s
               elsif line =~ /^IPV6Address:\s+(.+?)$/
                 info[:ipv6] = $1.to_s.strip
               elsif line =~ /^IPV6NetworkMaskPrefixLength:\s+(.+?)$/
                 info[:ipv6_prefix] = $1.to_s.strip
-              elsif status = line[/^Status:\s+(.+?)$/, 1]
-                info[:status] = status
+              elsif line =~ /^Status:\s+(.+?)$/
+                info[:status] = $1.to_s
               end
             end
 
@@ -350,9 +488,7 @@ module VagrantPlugins
         def read_mac_address
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            if mac = line[/^macaddress1="(.+?)"$/, 1]
-              return mac
-            end
+            return $1.to_s if line =~ /^macaddress1="(.+?)"$/
           end
 
           nil
@@ -373,8 +509,8 @@ module VagrantPlugins
 
         def read_machine_folder
           execute("list", "systemproperties", retryable: true).split("\n").each do |line|
-            if folder = line[/^Default machine folder:\s+(.+?)$/i, 1]
-              return folder
+            if line =~ /^Default machine folder:\s+(.+?)$/i
+              return $1.to_s
             end
           end
 
@@ -385,21 +521,21 @@ module VagrantPlugins
           nics = {}
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            if matcher = /^nic(\d+)="(.+?)"$/.match(line)
-              adapter = matcher[1].to_i
-              type    = matcher[2].to_sym
+            if line =~ /^nic(\d+)="(.+?)"$/
+              adapter = $1.to_i
+              type    = $2.to_sym
 
               nics[adapter] ||= {}
               nics[adapter][:type] = type
-            elsif matcher = /^hostonlyadapter(\d+)="(.+?)"$/.match(line)
-              adapter = matcher[1].to_i
-              network = matcher[2].to_s
+            elsif line =~ /^hostonlyadapter(\d+)="(.+?)"$/
+              adapter = $1.to_i
+              network = $2.to_s
 
               nics[adapter] ||= {}
               nics[adapter][:hostonly] = network
-            elsif matcher = /^bridgeadapter(\d+)="(.+?)"$/.match(line)
-              adapter = matcher[1].to_i
-              network = matcher[2].to_s
+            elsif line =~ /^bridgeadapter(\d+)="(.+?)"$/
+              adapter = $1.to_i
+              network = $2.to_s
 
               nics[adapter] ||= {}
               nics[adapter][:bridge] = network
@@ -413,8 +549,8 @@ module VagrantPlugins
           output = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           if output =~ /^name="<inaccessible>"$/
             return :inaccessible
-          elsif state = output[/^VMState="(.+?)"$/, 1]
-            return state.to_sym
+          elsif output =~ /^VMState="(.+?)"$/
+            return $1.to_sym
           end
 
           nil
@@ -423,7 +559,9 @@ module VagrantPlugins
         def read_used_ports
           ports = []
           execute("list", "vms", retryable: true).split("\n").each do |line|
-            if uuid = line[/^".+?" \{(.+?)\}$/, 1]
+            if line =~ /^".+?" \{(.+?)\}$/
+              uuid = $1.to_s
+
               # Ignore our own used ports
               next if uuid == @uuid
 
@@ -461,15 +599,26 @@ module VagrantPlugins
         end
 
         def set_name(name)
-          execute("modifyvm", @uuid, "--name", name)
+          execute("modifyvm", @uuid, "--name", name, retryable: true)
+        rescue Vagrant::Errors::VBoxManageError => e
+          raise if !e.extra_data[:stderr].include?("VERR_ALREADY_EXISTS")
+
+          # We got VERR_ALREADY_EXISTS. This means that we're renaming to
+          # a VM name that already exists. Raise a custom error.
+          raise Vagrant::Errors::VirtualBoxNameExists,
+            stderr: e.extra_data[:stderr]
         end
 
         def share_folders(folders)
           folders.each do |folder|
+            hostpath = folder[:hostpath]
+            if Vagrant::Util::Platform.windows?
+              hostpath = Vagrant::Util::Platform.windows_unc_path(hostpath)
+            end
             args = ["--name",
               folder[:name],
               "--hostpath",
-              folder[:hostpath]]
+              hostpath]
             args << "--transient" if folder.key?(:transient) && folder[:transient]
 
             # Enable symlinks on the shared folder
@@ -524,9 +673,9 @@ module VagrantPlugins
                 "--name", name,
                 "--transient")
 
-            execute(
-              "setextradata", @uuid,
-              "VBoxInternal2/SharedFoldersEnableSymlinksCreate/#{name}")
+              execute(
+                "setextradata", @uuid,
+                "VBoxInternal2/SharedFoldersEnableSymlinksCreate/#{name}")
             rescue Vagrant::Errors::VBoxManageError => e
               if e.extra_data[:stderr].include?("VBOX_E_FILE_ERROR")
                 # The folder doesn't exist. ignore.
@@ -537,20 +686,10 @@ module VagrantPlugins
           end
         end
 
-        def valid_ip_address?(ip)
-          # Filter out invalid IP addresses
-          # GH-4658 VirtualBox can report an IP address of 0.0.0.0 for FreeBSD guests.
-          if ip == "0.0.0.0"
-            return false
-          else
-            return true
-          end
-        end
-
         def verify!
           # This command sometimes fails if kernel drivers aren't properly loaded
           # so we just run the command and verify that it succeeded.
-          execute("list", "hostonlyifs")
+          execute("list", "hostonlyifs", retryable: true)
         end
 
         def verify_image(path)
@@ -563,9 +702,9 @@ module VagrantPlugins
             result = raw("showvminfo", uuid)
             return true if result.exit_code == 0
 
-            # GH-2479: Sometimes this happens. In this case, retry. If
-            # we don't see this text, the VM really probably doesn't exist.
-            return false if !result.stderr.include?("CO_E_SERVER_EXEC_FAILURE")
+            # If vboxmanage returned VBOX_E_OBJECT_NOT_FOUND,
+            # then the vm truly does not exist. Any other error might be transient
+            return false if result.stderr.include?("VBOX_E_OBJECT_NOT_FOUND")
 
             # Sleep a bit though to give VirtualBox time to fix itself
             sleep 2
@@ -577,6 +716,18 @@ module VagrantPlugins
           execute("showvminfo", uuid)
           return true
         end
+
+        protected
+
+        def valid_ip_address?(ip)
+          # Filter out invalid IP addresses
+          # GH-4658 VirtualBox can report an IP address of 0.0.0.0 for FreeBSD guests.
+          if ip == "0.0.0.0"
+            return false
+          else
+            return true
+          end
+        end
       end
     end
   end
