@@ -15,10 +15,14 @@ module VagrantPlugins
             if type == :forwarded_port
               guest_port = options[:guest]
               host_port  = options[:host]
+              protocol   = options[:protocol] || "tcp"
               options    = scoped_hash_override(options, :virtualbox)
               id         = options[:id]
 
-              mappings[host_port] =
+              # If the forwarded port was marked as disabled, ignore.
+              next if options[:disabled]
+
+              mappings[host_port.to_s + protocol.to_s] =
                 Model::ForwardedPort.new(id, host_port, guest_port, options)
             end
           end
