@@ -1,4 +1,5 @@
 require_relative "base"
+require_relative "../helpers"
 
 module VagrantPlugins
   module Ansible
@@ -8,12 +9,14 @@ module VagrantPlugins
         attr_accessor :provisioning_path
         attr_accessor :tmp_path
         attr_accessor :install
+        attr_accessor :install_mode
         attr_accessor :version
 
         def initialize
           super
 
           @install           = UNSET_VALUE
+          @install_mode      = UNSET_VALUE
           @provisioning_path = UNSET_VALUE
           @tmp_path          = UNSET_VALUE
           @version           = UNSET_VALUE
@@ -23,6 +26,7 @@ module VagrantPlugins
           super
 
           @install           = true                   if @install           == UNSET_VALUE
+          @install_mode      = :default               if @install_mode      == UNSET_VALUE
           @provisioning_path = "/vagrant"             if provisioning_path  == UNSET_VALUE
           @tmp_path          = "/tmp/vagrant-ansible" if tmp_path           == UNSET_VALUE
           @version           = ""                     if @version           == UNSET_VALUE
@@ -31,30 +35,13 @@ module VagrantPlugins
         def validate(machine)
           super
 
-          { "ansible local provisioner" => @errors }
-        end
-
-        protected
-
-        def check_path(machine, path, test_args, error_message_key = nil)
-          remote_path = Pathname.new(path).expand_path(@provisioning_path)
-          if machine.communicate.ready? && !machine.communicate.test("test #{test_args} #{remote_path}")
-            if error_message_key
-              @errors << I18n.t(error_message_key, path: remote_path, system: "guest")
-            end
-            return false
+          if @install_mode.to_s.to_sym == :pip
+            @install_mode = :pip
+          else
+            @install_mode = :default
           end
-          # when the machine is not ready for SSH communication,
-          # the check is "optimistically" by passed.
-          true
-        end
 
-        def check_path_is_a_file(machine, path, error_message_key = nil)
-          check_path(machine, path, "-f", error_message_key)
-        end
-
-        def check_path_exists(machine, path, error_message_key = nil)
-          check_path(machine, path, "-e", error_message_key)
+          { "ansible local provisioner" => @errors }
         end
 
       end
