@@ -112,6 +112,13 @@ describe VagrantPlugins::LoginCommand::Client do
       expect(subject.token).to eq("ABCD1234")
     end
 
+    it "prints a warning if the envvar and stored file are both present" do
+      stub_env("ATLAS_TOKEN" => "ABCD1234")
+      subject.store_token("EFGH5678")
+      expect(env.ui).to receive(:warn).with(/detected both/)
+      subject.token
+    end
+
     it "returns nil if there's no token set" do
       expect(subject.token).to be(nil)
     end
