@@ -22,6 +22,8 @@ describe VagrantPlugins::CommandSSHConfig::Command do
     host:             "testhost.vagrant.dev",
     port:             1234,
     username:         "testuser",
+    keys_only:        true,
+    paranoid:         false,
     private_key_path: [],
     forward_agent:    false,
     forward_x11:      false
@@ -92,8 +94,8 @@ Host #{machine.name}
 
       subject.execute
 
-      expect(output).to include('IdentityFile "foo"')
-      expect(output).to include('IdentityFile "bar"')
+      expect(output).to include("IdentityFile foo")
+      expect(output).to include("IdentityFile bar")
     end
 
     it "puts quotes around an identityfile path if it has a space" do
@@ -108,8 +110,9 @@ Host #{machine.name}
       expect(output).to include('IdentityFile "with a space"')
     end
 
-    it "escapes special characters" do
-      allow(machine).to receive(:ssh_info) { ssh_info.merge(private_key_path: ['/private/tmp/test of "vagrant" plugin/']) }
+    it "omits IdentitiesOnly when keys_only is false" do
+      allow(machine).to receive(:ssh_info) { ssh_info.merge(keys_only: false) }
+
       output = ""
       allow(subject).to receive(:safe_puts) do |data|
         output += data if data
@@ -117,7 +120,21 @@ Host #{machine.name}
 
       subject.execute
 
-      expect(output).to include('"/private/tmp/test of \"vagrant\" plugin/"')
+      expect(output).not_to include('IdentitiesOnly')
+    end
+
+    it "omits StrictHostKeyChecking and UserKnownHostsFile when paranoid is true" do
+      allow(machine).to receive(:ssh_info) { ssh_info.merge(paranoid: true) }
+
+      output = ""
+      allow(subject).to receive(:safe_puts) do |data|
+        output += data if data
+      end
+
+      subject.execute
+
+      expect(output).not_to include('StrictHostKeyChecking ')
+      expect(output).not_to include('UserKnownHostsFile ')
     end
   end
 end
