@@ -17,7 +17,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
   let(:env) { {
     box_collection: box_collection,
     hook: Proc.new { |name, env| env },
-    tmp_path: Pathname.new(Dir.mktmpdir),
+    tmp_path: Pathname.new(Dir.mktmpdir("vagrant-test-builtin-box-add")),
     ui: Vagrant::UI::Silent.new,
   } }
 
@@ -31,6 +31,10 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
     Vagrant::Box.new("foo", :virtualbox, "1.0", box_dir)
   end
 
+  after do
+    FileUtils.rm_rf(env[:tmp_path])
+  end
+
   # Helper to quickly SHA1 checksum a path
   def checksum(path)
     FileChecksum.new(path, Digest::SHA1).checksum
@@ -39,9 +43,6 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
   def with_ftp_server(path, **opts)
     path = Pathname.new(path)
 
-    tf = Tempfile.new("vagrant")
-    tf.close
-
     port = nil
     server = nil
     with_random_port do |port1, port2|
@@ -56,7 +57,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
   end
 
   def with_web_server(path, **opts)
-    tf = Tempfile.new("vagrant")
+    tf = Tempfile.new("vagrant-web-server")
     tf.close
 
     opts[:json_type] ||= "application/json"
@@ -74,6 +75,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
     thr = Thread.new { server.start }
     yield port
   ensure
+    tf.unlink
     server.shutdown rescue nil
     thr.join rescue nil
   end
@@ -282,7 +284,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
   context "with box metadata" do
     it "adds from HTTP URL" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new(["vagrant", ".json"]).tap do |f|
+      tf = Tempfile.new(["vagrant-test-box-http-url", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -325,7 +327,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds from HTTP URL with complex JSON mime type" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new(["vagrant", ".json"]).tap do |f|
+      tf = Tempfile.new(["vagrant-test-http-json", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -370,7 +372,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds from shorthand path" do
       box_path = iso_env.box2_file(:virtualbox)
-      td = Pathname.new(Dir.mktmpdir)
+      td = Pathname.new(Dir.mktmpdir("vagrant-test-box-add-shorthand-path"))
       tf = td.join("mitchellh", "precise64.json")
       tf.dirname.mkpath
       tf.open("w") do |f|
@@ -414,11 +416,13 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
           subject.call(env)
         end
       end
+
+      FileUtils.rm_rf(td)
     end
 
     it "add from shorthand path with configured server url" do
       box_path = iso_env.box2_file(:virtualbox)
-      td = Pathname.new(Dir.mktmpdir)
+      td = Pathname.new(Dir.mktmpdir("vagrant-test-box-add-server-url"))
       tf = td.join("mitchellh", "precise64.json")
       tf.dirname.mkpath
       tf.open("w") do |f|
@@ -461,11 +465,13 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
         subject.call(env)
       end
+
+      FileUtils.rm_rf(td)
     end
 
     it "authenticates HTTP URLs and adds them" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new(["vagrant", ".json"]).tap do |f|
+      tf = Tempfile.new(["vagrant-test-http", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -523,7 +529,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds from HTTP URL with a checksum" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new(["vagrant", ".json"]).tap do |f|
+      tf = Tempfile.new(["vagrant-test-http-checksum", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -568,7 +574,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "raises an exception if checksum given but not correct" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new(["vagrant", ".json"]).tap do |f|
+      tf = Tempfile.new(["vagrant-test-bad-checksum", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -606,9 +612,6 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
     end
 
     it "raises an error if no Vagrant server is set" do
-      tf = Tempfile.new("foo")
-      tf.close
-
       env[:box_url] = "mitchellh/precise64.json"
 
       expect(box_collection).to receive(:add).never
@@ -621,10 +624,9 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
     end
 
     it "raises an error if shorthand is invalid" do
-      tf = Tempfile.new("foo")
-      tf.close
+      path = Dir::Tmpname.create("vagrant-shorthand-invalid") {}
 
-      with_web_server(Pathname.new(tf.path)) do |port|
+      with_web_server(Pathname.new(path)) do |port|
         env[:box_url] = "mitchellh/precise64.json"
 
         expect(box_collection).to receive(:add).never
@@ -640,7 +642,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "raises an error if multiple metadata URLs are given" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-multi-metadata", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -676,7 +678,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds the latest version of a box with only one provider" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-latest-version", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -715,7 +717,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds the latest version of a box with the specified provider" do
       box_path = iso_env.box2_file(:vmware)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-specific-provider", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -761,7 +763,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds the latest version of a box with the specified provider, even if not latest" do
       box_path = iso_env.box2_file(:vmware)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-specified-provider", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -810,7 +812,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds the constrained version of a box with the only provider" do
       box_path = iso_env.box2_file(:vmware)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-constrained", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -850,7 +852,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds the constrained version of a box with the specified provider" do
       box_path = iso_env.box2_file(:vmware)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-constrained-provider", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -895,7 +897,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "adds the latest version of a box with any specified provider" do
       box_path = iso_env.box2_file(:vmware)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-latest-version", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -943,7 +945,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "asks the user what provider if multiple options" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-provider-asks", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -989,7 +991,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "raises an exception if the name doesn't match a requested name" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-name-mismatch", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -1024,7 +1026,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "raises an exception if no matching version" do
       box_path = iso_env.box2_file(:vmware)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-no-matching-version", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -1055,7 +1057,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
     end
 
     it "raises an error if there is no matching provider" do
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-no-matching-provider", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -1089,7 +1091,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "raises an error if a box already exists" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-already-exists", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
@@ -1124,7 +1126,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
     it "force adds a box if specified" do
       box_path = iso_env.box2_file(:virtualbox)
-      tf = Tempfile.new("vagrant").tap do |f|
+      tf = Tempfile.new(["vagrant-box-force-add", ".json"]).tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo/bar",
