@@ -227,7 +227,7 @@ describe Vagrant::Box, :skip_windows do
 
   context "#load_metadata" do
     let(:metadata_url) do
-      Tempfile.new("vagrant").tap do |f|
+      Tempfile.new("vagrant-test-box-test").tap do |f|
         f.write(<<-RAW)
         {
           "name": "foo",
@@ -244,6 +244,10 @@ describe Vagrant::Box, :skip_windows do
         metadata_url: metadata_url.path)
     end
 
+    after do
+      metadata_url.unlink
+    end
+
     it "loads the url and returns the data" do
       result = subject.load_metadata
       expect(result.name).to eq("foo")
@@ -286,6 +290,14 @@ describe Vagrant::Box, :skip_windows do
   end
 
   describe "repackaging" do
+    let(:scratch) { Dir.mktmpdir("vagrant-test-box-repackaging") }
+
+    let(:box_output_path) { File.join(scratch, "package.box") }
+
+    after do
+      FileUtils.rm_rf(scratch)
+    end
+
     it "should repackage the box" do
       test_file_contents = "hello, world!"
 
@@ -296,7 +308,6 @@ describe Vagrant::Box, :skip_windows do
       end
 
       # Repackage our box to some temporary directory
-      box_output_path = temporary_dir.join("package.box")
       expect(subject.repackage(box_output_path)).to be_true
 
       # Let's now add this box again under a different name, and then
